@@ -4,33 +4,29 @@ not bound to a specific higher level UP42 object.
 """
 
 import json
-
+from functools import wraps
 from pathlib import Path
 from typing import List, Union, Dict, Optional
 from datetime import date, datetime, timedelta
-from geopandas import GeoDataFrame
 
 import requests.exceptions
 import geopandas as gpd
+from geopandas import GeoDataFrame
 import pandas as pd
 import shapely
 
-from up42.viztools import folium_base_map, DrawFoliumOverride
 from up42.utils import get_logger, format_time_period
 
-try:
-    from IPython import get_ipython
-
-    get_ipython().run_line_magic("matplotlib", "inline")
-except (ImportError, AttributeError):
-    # No Ipython installed, Installed but run in shell
-    pass
-
 logger = get_logger(__name__)
 
 
 def check_auth(func, *args, **kwargs):
+    """
+    Some functionality of the up42 import object (which integrates Tools functions) can theoretically be used
+    before authentication with UP42, so the auth needs to be checked first.
+    """
     # pylint: disable=unused-argument
+    @wraps(func)  # required for mkdocstrings
     def inner(self, *args, **kwargs):
         if not hasattr(self, "auth"):
             raise Exception(
@@ -126,38 +122,12 @@ class Tools:
         else:
             return example_aoi
 
-    @staticmethod
-    def draw_aoi():
-        """
-        Displays an interactive map to draw an aoi by hand, returns the folium object if
-        not run in a Jupyter notebook.
-
-        Export the drawn aoi via the export button, then read the geometries via
-        read_aoi_file().
-        """
-        m = folium_base_map(layer_control=True)
-        DrawFoliumOverride(
-            export=True,
-            filename="aoi.geojson",
-            position="topleft",
-            draw_options={
-                "rectangle": {"repeatMode": False, "showArea": True},
-                "polygon": {"showArea": True, "allowIntersection": False},
-                "polyline": False,
-                "circle": False,
-                "marker": False,
-                "circlemarker": False,
-            },
-            edit_options={"polygon": {"allowIntersection": False}},
-        ).add_to(m)
-        return m
-
     @check_auth
     def get_blocks(
         self,
         block_type: Optional[str] = None,
         basic: bool = True,
-        as_dataframe=False,
+        as_dataframe: bool = False,
     ) -> Union[List[Dict], dict]:
         """
         Gets a list of all public blocks on the marketplace. Can not access custom blocks.
@@ -275,9 +245,10 @@ class Tools:
         account.
         Args:
             start_date: The start date for the credit consumption search e.g.
-            2021-12-01. Default start_date None uses 2000-01-01.
+                2021-12-01. Default start_date None uses 2000-01-01.
             end_date: The end date for the credit consumption search e.g.
-            2021-12-31. Default end_date None uses current date.
+                2021-12-31. Default end_date None uses current date.
+
         Returns:
             A dict with the information of the credit consumption records for
             all the users linked by the account_id.
